@@ -84,8 +84,7 @@ class Display:
         return removedOptions
 
     def RemoveAllOptions(self):
-        """Remove all of the options in the list
-        """
+        """Remove all of the options in the list"""
         self.options = {}
 
     def ShowHeader(self, *, text: str = "Display.py"):
@@ -172,7 +171,7 @@ W: Up, A: Left, S: Down, D: Right, Q: Quit, Enter: Select"""
                 lower=self.__lowest,
                 higher=self.__highest,
             )
-            return self.options.get(v)[0](self.options.get(v)[1])
+            return self.options.get(v)[0](self.options.get(v)[1:])
         except TypeError:
             Message().clear("Invalid input!", timeS=2, colour="red")
             return None
@@ -238,7 +237,7 @@ W: Up, A: Left, S: Down, D: Right, Q: Quit, Enter: Select"""
                     self.options.get(
                         self.gridData[self.cursorPosition[1]
                                       ][self.cursorPosition[0]]
-                    )[1]
+                    )[1:]
                 )
 
             elif c == "q":
